Pipeline API
===========

The ``pipeline`` module provides the main entry point for the Hydro-Topo Features package. It contains functions for running the complete pipeline for extracting hydro-topographic features.

.. automodule:: hydro_topo_features.pipeline
   :members:
   :undoc-members:
   :show-inheritance:

Main Pipeline Function
--------------------

.. autofunction:: hydro_topo_features.pipeline.run_pipeline

Directory Structure Setup
-----------------------

.. autofunction:: hydro_topo_features.pipeline.setup_directory_structure

Visualization Functions
---------------------

.. autofunction:: hydro_topo_features.pipeline.create_static_visualizations

.. autofunction:: hydro_topo_features.pipeline.create_interactive_visualization 